// Copyright 2003 Regents of the University of California

// SETI_BOINC is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 2, or (at your option) any later
// version.

// SETI_BOINC is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
// more details.

// You should have received a copy of the GNU General Public License along
// with SETI_BOINC; see the file COPYING.  If not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

// $Id: seti.h,v 1.19 2005/02/17 00:30:03 korpela Exp $
#ifndef _SETI_H
#define _SETI_H

#include "analyze.h"
#include "seti_header.h"
#include "malloc_a.h"

struct ANALYSIS_STATE {
  float* data;
  float* savedWUData;    // Save the original WU data
  int npoints;
  int icfft;
  int PoT_freq_bin;   // where we are in PoT analysis for this icfft
  // ... will be -1 if no PoT analysis in progress
  int PoT_activity;
  int doing_pulse;
};

extern bool nographics_flag;
extern int seti_init_state();
extern int seti_do_work();
extern int result_group_start();
extern int result_group_write_header();
extern int result_group_end();
extern int checkpoint(BOOLEAN force_checkpoint=0);
extern int seti_parse_wu(FILE*, ANALYSIS_STATE&);
extern int parse_state_file(ANALYSIS_STATE& as);

extern ANALYSIS_STATE analysis_state;
extern SETI_WU_INFO swi;

#ifndef GUISO
class SAH_GRAPHICS_BASE;
extern SAH_GRAPHICS_BASE *sah_graphics;
#else
class SAH_GRAPHICS;
extern SAH_GRAPHICS *sah_graphics;
#endif

#ifdef DYNAMIC_GRAPHICS
typedef int (*int_func_t)();
extern int_func_t glut_is_initialized;
#endif

inline bool nographics() {
#ifdef BOINC_APP_GRAPHICS
#ifdef DYNAMIC_GRAPHICS
  return (nographics_flag || !sah_graphics || !graphics_lib_handle ||
      !(glut_is_initialized && glut_is_initialized()));
#else
  return (nographics_flag || !sah_graphics );
      // || !xwin_glut_is_initialized());    // should add this back somehow
#endif
#else
  return true;
#endif
}

struct SPIKE_INFO {
public :
 SPIKE_INFO();
  ~SPIKE_INFO();
  SPIKE_INFO(const SPIKE_INFO &si);
  SPIKE_INFO &operator =(const SPIKE_INFO &si);
  spike s;		
  double score;		// calc in ReportEvents()
  int bin;		// assigned in ReportEvents()
  int fft_ind;		// assigned in ReportEvents()
};

struct GAUSS_INFO {
public :
  GAUSS_INFO();
  ~GAUSS_INFO();
  GAUSS_INFO(const GAUSS_INFO &gi);
  GAUSS_INFO &operator =(const GAUSS_INFO &gi);
  gaussian g;
  double score;		// calc in ReportGaussEvent()
  double display_power_thresh;	// calc in gaussfit()
  int bin;		// assigned in ReportGaussEvent()
  int fft_ind;		// assigned in ReportGaussEvent()
  //float * pot;
};

struct PULSE_INFO {
public :
  PULSE_INFO();
  ~PULSE_INFO();
  PULSE_INFO(const PULSE_INFO &pi);
  PULSE_INFO &operator =(const PULSE_INFO &pi);
  pulse p;
  double score;		// calc in ReportPulseEvent()
  int freq_bin;		// assigned in ReportPulseEvent()
  int time_bin;		// assigned in ReportPulseEvent()
  unsigned int * pot_min;  // Scaled 0-255 for display
  unsigned int * pot_max;  // Scaled 0-255 for display
};

struct TRIPLET_INFO {
public :
  TRIPLET_INFO();
  ~TRIPLET_INFO();
  TRIPLET_INFO(const TRIPLET_INFO &ti);
  TRIPLET_INFO &operator =(const TRIPLET_INFO &ti);
  triplet t;
  double score;		// assigned in ReportTripletEvent()
  double bperiod;	// probably deprecated - remove sometime
  int freq_bin;		// assigned in ReportTripletEvent()
  			// ticks below assigned in ReportTripletEvent()
  int tpotind0_0;	// index into pot_min/pot_max arrays
  int tpotind0_1;	// of start/end of first element of triplet
  int tpotind1_0;	// second element
  int tpotind1_1;
  int tpotind2_0;	// and third element
  int tpotind2_1;
  double time_bin;	// calc in ReportTripletEvent()
  double scale;      	// Scale from PoT bins to TRIPLET_POT_LEN
  unsigned int * pot_min;  // Scaled 0-255 for display
  unsigned int * pot_max;  // Scaled 0-255 for display
};

#endif
